==> openGion8.4.3.0_src.zip: uap/webapps/gf/jsp/common/scrollBar2.js <==
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.findInternal=function(a,h,f){a instanceof String&&(a=String(a));for(var d=a.length,b=0;b<d;b++){var c=a[b];if(h.call(f,c,b,a))return{i:b,v:c}}return{i:-1,v:void 0}};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;
$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,h,f){if(a==Array.prototype||a==Object.prototype)return a;a[h]=f.value;return a};$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var h=0;h<a.length;++h){var f=a[h];if(f&&f.Math==Math)return f}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);
$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,h){var f=$jscomp.propertyToPolyfillSymbol[h];if(null==f)return a[h];f=a[f];return void 0!==f?f:a[h]};
$jscomp.polyfill=function(a,h,f,d){h&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,h,f,d):$jscomp.polyfillUnisolated(a,h,f,d))};$jscomp.polyfillUnisolated=function(a,h,f,d){f=$jscomp.global;a=a.split(".");for(d=0;d<a.length-1;d++){var b=a[d];if(!(b in f))return;f=f[b]}a=a[a.length-1];d=f[a];h=h(d);h!=d&&null!=h&&$jscomp.defineProperty(f,a,{configurable:!0,writable:!0,value:h})};
$jscomp.polyfillIsolated=function(a,h,f,d){var b=a.split(".");a=1===b.length;d=b[0];d=!a&&d in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var c=0;c<b.length-1;c++){var e=b[c];if(!(e in d))return;d=d[e]}b=b[b.length-1];f=$jscomp.IS_SYMBOL_NATIVE&&"es6"===f?d[b]:null;h=h(f);null!=h&&(a?$jscomp.defineProperty($jscomp.polyfills,b,{configurable:!0,writable:!0,value:h}):h!==f&&(void 0===$jscomp.propertyToPolyfillSymbol[b]&&(f=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[b]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(b):$jscomp.POLYFILL_PREFIX+f+"$"+b),$jscomp.defineProperty(d,$jscomp.propertyToPolyfillSymbol[b],{configurable:!0,writable:!0,value:h})))};$jscomp.polyfill("Array.prototype.find",function(a){return a?a:function(h,f){return $jscomp.findInternal(this,h,f).v}},"es6","es3");
function scrollBar2(a){alert("Old Script Error!!\ncustom/query_info.jsp,custom/result_info.jsp Please delete the following part.\n<script>Tag(Header fix and Focus) , BODY onLoad and oncontextmenu Attribute. scrollBar2(...)")}function SetScrollHeader(a){}
(function(a){a.hgrid=a.hgrid||{};a.hgrid.defaults={sGantBody:"GantBody",sViewTable:"viewTable",sGridList:"GridList",sInAdjusting:"__bInAdjusting"};a.hgrid.load=function(d){var b=a("div > div > div > div > table.viewTable");if(0==a("body").width()||100==a("body").width())setTimeout(function(){a.hgrid.on("load",d)},1);else{var c=a("#"+a.hgrid.defaults.sGantBody+":first");a(window).data("gantBody",c);0<c.length&&2==b.length&&c.heightReset();b.each(function(e){f(a(this))});b.hybsGrid().adjustSB();focus2&&
focus2()}};a.hgrid.resize=function(d){a(this).data(a.hgrid.defaults.sInAdjusting)||(a(this).data(a.hgrid.defaults.sInAdjusting,!0),setTimeout(function(){var b=a.hgrid.defaults.sGridList;(b=a(window).data(b))&&a.each(b,function(){a(this.oTab).adjustSB()});a(window).data(a.hgrid.defaults.sInAdjusting,!1)},100))};a.hgrid.unload=function(d){d=a.hgrid.defaults.sGridList;var b=a(this).data(d);b&&(a.each(b,function(){this.oTab.grid=this.oTab.p=null}),b.length=0);a(this).removeData(d);a.hgrid=null};a(window).off("load.hgrid").on("load.hgrid",
a.hgrid.load).off("resize.hgrid").on("resize.hgrid",a.hgrid.resize).off("unload.hgrid").on("unload.hgrid",a.hgrid.unload);var h=function(){var d;return function(){var b;if(!(b=d)){b=a('<div style="width:50px;height:50px;overflow:hidden;position:absolute;top:-200px;left:-200px;"><div style="height:100px;"></div>');a("body").append(b);var c=a("div",b).innerWidth();b.css("overflow-y","scroll");var e=a("div",b).innerWidth();0==c-e&&(e=c-17);a(b).remove();b=d=c-e}return b}}(),f=function(d){if(!d.data("cache")){d.parent().attr("id",
"divHide2").css({width:"10000em"});var b=[],c=a("thead:first",d),e=a("tr th",c);d.data("thead",c);d.data("trTh",e);e.each(function(q){b[q]=a(this).width()});d.data("thw",b);c=a.hybs.getHybsTr(d.find("tbody tr:first"));d.data("firstTr",c);e=c.height();d.data("trh",e);var g=[],l=[];c=a("td",c);d.data("firstTrTd",c);c.each(function(q){0<a(this).find(".h_evElm").length&&("true"==a(this).attr("wa")&&a(this).css("width","auto"),"true"==a(this).attr("ha")&&a(this).css("height","auto"),"auto"==a(this).css("width")&&
a(this).attr("wa","true"),"auto"==a(this).css("height")&&a(this).attr("ha","true"));g[q]=a(this).width();l[q]=a(this).height()});d.data("tdw",g);d.data("tdh",l);d.data("cache",!0)}};a.fn.heightReset=function(d){p=a.extend(!0,{},a.hgrid.defaults,d||{});return this.each(function(){var b=a("table."+p.sViewTable,this),c=b.get(0);b=b.get(1);var e=c.rows,g=b.rows,l=c.rows.length,q=c.tHead.rows.length;for(k=0;k<q;k++){var n=Math.max(c.rows[k].offsetHeight,b.rows[k].offsetHeight);e[k].style.height=g[k].style.height=
n+"px"}n=0;var k;for(k=q;k<l&&k<q+5;k++)n=Math.max(n,Math.max(e[k].offsetHeight,g[k].offsetHeight));for(k=q;k<l;k++)e[k].style.height=g[k].style.height=n+"px"})};a.fn.hybsGrid=function(d){d=a.extend(!0,{selrow:null,multiselect:!1,multikey:!1,nHoriExtra:16,nVertExtra:10,nMinLimit:50,nWidthScroll:h(),bX1VScroll:!1,bX2VScroll:!0},a.hgrid.defaults,d||{});var b={scrollGrid:function(){var c=this.bDiv.scrollTop;this.hDiv.scrollLeft=this.bDiv.scrollLeft;if(this.oPrev){var e=this.oPrev.grid.bDiv;c!=e.scrollTop&&
(e.scrollTop=c)}this.oNext&&(e=this.oNext.grid.bDiv,c!=e.scrollTop&&(e.scrollTop=c))}};a.fn.adjustSB=function(c){return this.each(function(){if(this.grid){"boolean"!=typeof c&&(c=!0);var e=a(this);var g=this.grid.hTable.parentNode;g.style.width&&(g.style.width=this.grid.hTable.offsetWidth+"px");g=this.grid.bHide;var l=a("thead:first",this);l=l.outerHeight()+2*l[0].offsetTop;g.style.width=e.outerWidth()+"px";g.style.height=e.outerHeight()-l+"px";g.scrollTop=l;for(var q=0,n=0;;){l=a(window).width();
var k=a(window).height();e=a(this.grid.bDiv);var u=e.offset();var r=this.grid.oNext;var t=this.grid.oPrev;l=Math.max(l-Math.ceil(u.left)-this.p.nHoriExtra,this.p.nMinLimit);k=Math.max(k-Math.ceil(u.top)-this.p.nVertExtra,this.p.nMinLimit);l=this.p.width?0>this.p.width.indexOf("%")?parseInt(this.p.width,10):l*(parseInt(this.p.width,10)/100):l;k=this.p.height?0>this.p.height.indexOf("%")?parseInt(this.p.height,10):k*(parseInt(this.p.height,10)/100):k;if(l<=q&&k<=n)break;var w=this.offsetWidth,y=g.offsetHeight;
q=l;n=k;var m=q-w;var v=n-y;var x=0>m;u=0>v;var z;var A=z=!1;!x&&this.p.nWidthScroll>m&&(A=u||this.p.nWidthScroll>v);!u&&this.p.nWidthScroll>v&&(z=x||this.p.nWidthScroll>m);t&&t.grid.bHoriScroll&&(A=!1);A&&(x=!0);z&&(u=!0);r&&!this.p.bX1VScroll&&(u=!1);r=x?"scroll":"hidden";m=u?"scroll":"hidden";q=Math.min(q,w+(u?this.p.nWidthScroll:0));n=Math.min(n,y+(x?this.p.nWidthScroll:0));this.grid.bHoriScroll=x;this.grid.bVertScroll=u;this.grid.width=q;this.grid.height=n;t&&(x=n-(x?this.p.nWidthScroll:0)+(t.grid.bHoriScroll?
this.p.nWidthScroll:0),x!=t.grid.height&&(t.grid.height=x,w=t.grid.hDiv.offsetHeight,a(t.grid.bDiv).css("height",x+"px").parent().css({height:x+w+"px"})));a(this.grid.hDiv).width(q-(u?this.p.nWidthScroll:0));this.grid.firstRowHeight&&(t=this.grid.firstRowHeight,this.grid.firstRowHeight=null,a(this.grid.hDiv).height(this.grid.hDiv.offsetHeight-t));t=this.grid.hDiv.offsetHeight;e.css({width:q+"px",height:n+"px","overflow-x":r,"overflow-y":m}).parent().css({height:n+t+"px",width:q+"px"});q=l;n=k}this.grid.scrollGrid()}})};
return this.each(function(c){if("divHide"==this.parentNode.id||"divHide2"==this.parentNode.id){var e=this,g=a(e);c=a.extend(!0,{},b);var l=a.extend(!0,{},d),q=l.colModel=[];f(g);g.data("trTh").each(function(m){var v=a(this);v=v.attr("field")||v.text();q[m]={name:v,index:v,width:g.data("thw")[m]}});var n=!1,k=g.data("firstTr"),u=a(window).data("gantBody");0<u.length&&(n=!0);g.addClass("scroll");var r=e.parentNode;c.bHide=e.parentNode;c.bDiv=c.bHide.parentNode;(r=g.parents("#divPos")[0])&&a.each(["width",
"height"],function(){e.p&&e.p[this]?l[this]=e.p[this]:r.style[this]&&(l[this]=r.style[this],r.style[this]="auto")});a.each(l.colModel,function(m){"undefined"==typeof this.width&&(this.width=150)});var t=g.data("thead").get(0);g.data("trTh").each(function(m){"true"==a(this).attr("plusone")?a(this).css("width",l.colModel[m].width+"px"):(a(this).css("width",l.colModel[m].width+1+"px"),a(this).attr("plusone","true"))});c.hTable=document.createElement("table");var w=a(c.hTable);w.addClass(g.attr("class")).css({margin:"0px"});
a.each("cellspacing cellpadding border bordercolor frame rules".split(" "),function(m,v){g.attr(v)&&w.attr(v,g.attr(v))});w.attr("id","headerTable");g.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","").removeClass("visihidden")});r=t;t=a("#header",g);var y=[];for(a("input,select,textarea",t).each(function(m){"checkbox"==a(this).attr("type")?a(this).prop("checked")?y[m]="1":y[m]="0":y[m]=a(this).val()});r;)w.prepend(a(r).clone(!0)),r=r.previousSibling;
t=a(w).find("#header");a("input,select,textarea",t).each(function(m){"checkbox"==a(this).attr("type")?"1"==y[m]&&a(this).prop("checked",!0):a(this).val(y[m])});n&&k&&k[0]&&(c.firstRowHeight=g.data("trh")+1,a("td",k).each(function(m){a(this).css("width",g.data("tdw")[m]+"px").css("height",g.data("tdh")[m]+"px")}),jTrCl=k.clone(),a("td",jTrCl).each(function(m){a(this).html(""==a(this).text()?"":" ").css("backgroundColor","transparent")}),jAddTo=jTrCl.is("tr")?a(document.createElement("tbody")).appendTo(w):
w,jAddTo.append(jTrCl));c.hDiv=document.createElement("div");a(c.hDiv).attr("class","hGrid-header").append(a('<div style="width:10000em;" />').append(c.hTable));g.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","999").addClass("visihidden")});"hGrid-header"==a(c.bDiv).prev().attr("class")&&a(c.bDiv).prev().remove();a(c.bDiv).before(c.hDiv);a(c.bDiv).on("scroll",function(m){(m=a("table:first",m.target)[0])&&m.grid&&m.grid.scrollGrid()});r=a(window).data(l.sGridList);
0<u.length&&r&&(n=r[r.length-1],n.oWrap===u[0]&&(n.oTab.grid.oNext=e,c.oPrev=n.oTab));r||(r=[]);r.push({oTab:e,oWrap:u[0]});a(window).data(l.sGridList,r);g.data("cache",!1);e.grid=c;e.p=l;e=g=r=u=c=l=null}})}})(jQuery);

==> openGion8.5.0.0_src.zip: uap/webapps/gf/jsp/common/scrollBar2.js <==
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.findInternal=function(a,h,f){a instanceof String&&(a=String(a));for(var d=a.length,b=0;b<d;b++){var c=a[b];if(h.call(f,c,b,a))return{i:b,v:c}}return{i:-1,v:void 0}};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;
$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,h,f){if(a==Array.prototype||a==Object.prototype)return a;a[h]=f.value;return a};$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var h=0;h<a.length;++h){var f=a[h];if(f&&f.Math==Math)return f}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);
$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,h){var f=$jscomp.propertyToPolyfillSymbol[h];if(null==f)return a[h];f=a[f];return void 0!==f?f:a[h]};
$jscomp.polyfill=function(a,h,f,d){h&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,h,f,d):$jscomp.polyfillUnisolated(a,h,f,d))};$jscomp.polyfillUnisolated=function(a,h,f,d){f=$jscomp.global;a=a.split(".");for(d=0;d<a.length-1;d++){var b=a[d];if(!(b in f))return;f=f[b]}a=a[a.length-1];d=f[a];h=h(d);h!=d&&null!=h&&$jscomp.defineProperty(f,a,{configurable:!0,writable:!0,value:h})};
$jscomp.polyfillIsolated=function(a,h,f,d){var b=a.split(".");a=1===b.length;d=b[0];d=!a&&d in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var c=0;c<b.length-1;c++){var e=b[c];if(!(e in d))return;d=d[e]}b=b[b.length-1];f=$jscomp.IS_SYMBOL_NATIVE&&"es6"===f?d[b]:null;h=h(f);null!=h&&(a?$jscomp.defineProperty($jscomp.polyfills,b,{configurable:!0,writable:!0,value:h}):h!==f&&(void 0===$jscomp.propertyToPolyfillSymbol[b]&&(f=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[b]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(b):$jscomp.POLYFILL_PREFIX+f+"$"+b),$jscomp.defineProperty(d,$jscomp.propertyToPolyfillSymbol[b],{configurable:!0,writable:!0,value:h})))};$jscomp.polyfill("Array.prototype.find",function(a){return a?a:function(h,f){return $jscomp.findInternal(this,h,f).v}},"es6","es3");
function scrollBar2(a){alert("Old Script Error!!\ncustom/query_info.jsp,custom/result_info.jsp Please delete the following part.\n<script>Tag(Header fix and Focus) , BODY onLoad and oncontextmenu Attribute. scrollBar2(...)")}function SetScrollHeader(a){}
(function(a){a.hgrid=a.hgrid||{};a.hgrid.defaults={sGantBody:"GantBody",sViewTable:"viewTable",sGridList:"GridList",sInAdjusting:"__bInAdjusting"};a.hgrid.load=function(d){var b=a("div > div > div > div > table.viewTable");if(0==a("body").width()||100==a("body").width())setTimeout(function(){a.hgrid.load(d)},1);else{var c=a("#"+a.hgrid.defaults.sGantBody+":first");a(window).data("gantBody",c);0<c.length&&2==b.length&&c.heightReset();b.each(function(e){f(a(this))});b.hybsGrid().adjustSB();focus2&&
focus2()}};a.hgrid.resize=function(d){a(this).data(a.hgrid.defaults.sInAdjusting)||(a(this).data(a.hgrid.defaults.sInAdjusting,!0),setTimeout(function(){var b=a.hgrid.defaults.sGridList;(b=a(window).data(b))&&a.each(b,function(){a(this.oTab).adjustSB()});a(window).data(a.hgrid.defaults.sInAdjusting,!1)},100))};a.hgrid.unload=function(d){d=a.hgrid.defaults.sGridList;var b=a(this).data(d);b&&(a.each(b,function(){this.oTab.grid=this.oTab.p=null}),b.length=0);a(this).removeData(d);a.hgrid=null};a(window).off("load.hgrid").on("load.hgrid",
a.hgrid.load).off("resize.hgrid").on("resize.hgrid",a.hgrid.resize).off("unload.hgrid").on("unload.hgrid",a.hgrid.unload);var h=function(){var d;return function(){var b;if(!(b=d)){b=a('<div style="width:50px;height:50px;overflow:hidden;position:absolute;top:-200px;left:-200px;"><div style="height:100px;"></div>');a("body").append(b);var c=a("div",b).innerWidth();b.css("overflow-y","scroll");var e=a("div",b).innerWidth();0==c-e&&(e=c-17);a(b).remove();b=d=c-e}return b}}(),f=function(d){if(!d.data("cache")){d.parent().attr("id",
"divHide2").css({width:"10000em"});var b=[],c=a("thead:first",d),e=a("tr th",c);d.data("thead",c);d.data("trTh",e);e.each(function(q){b[q]=a(this).width()});d.data("thw",b);c=a.hybs.getHybsTr(d.find("tbody tr:first"));d.data("firstTr",c);e=c.height();d.data("trh",e);var g=[],l=[];c=a("td",c);d.data("firstTrTd",c);c.each(function(q){0<a(this).find(".h_evElm").length&&("true"==a(this).attr("wa")&&a(this).css("width","auto"),"true"==a(this).attr("ha")&&a(this).css("height","auto"),"auto"==a(this).css("width")&&
a(this).attr("wa","true"),"auto"==a(this).css("height")&&a(this).attr("ha","true"));g[q]=a(this).width();l[q]=a(this).height()});d.data("tdw",g);d.data("tdh",l);d.data("cache",!0)}};a.fn.heightReset=function(d){p=a.extend(!0,{},a.hgrid.defaults,d||{});return this.each(function(){var b=a("table."+p.sViewTable,this),c=b.get(0);b=b.get(1);var e=c.rows,g=b.rows,l=c.rows.length,q=c.tHead.rows.length;for(k=0;k<q;k++){var n=Math.max(c.rows[k].offsetHeight,b.rows[k].offsetHeight);e[k].style.height=g[k].style.height=
n+"px"}n=0;var k;for(k=q;k<l&&k<q+5;k++)n=Math.max(n,Math.max(e[k].offsetHeight,g[k].offsetHeight));for(k=q;k<l;k++)e[k].style.height=g[k].style.height=n+"px"})};a.fn.hybsGrid=function(d){d=a.extend(!0,{selrow:null,multiselect:!1,multikey:!1,nHoriExtra:16,nVertExtra:10,nMinLimit:50,nWidthScroll:h(),bX1VScroll:!1,bX2VScroll:!0},a.hgrid.defaults,d||{});var b={scrollGrid:function(){var c=this.bDiv.scrollTop;this.hDiv.scrollLeft=this.bDiv.scrollLeft;if(this.oPrev){var e=this.oPrev.grid.bDiv;c!=e.scrollTop&&
(e.scrollTop=c)}this.oNext&&(e=this.oNext.grid.bDiv,c!=e.scrollTop&&(e.scrollTop=c))}};a.fn.adjustSB=function(c){return this.each(function(){if(this.grid){"boolean"!=typeof c&&(c=!0);var e=a(this);var g=this.grid.hTable.parentNode;g.style.width&&(g.style.width=this.grid.hTable.offsetWidth+"px");g=this.grid.bHide;var l=a("thead:first",this);l=l.outerHeight()+2*l[0].offsetTop;g.style.width=e.outerWidth()+"px";g.style.height=e.outerHeight()-l+"px";g.scrollTop=l;for(var q=0,n=0;;){l=a(window).width();
var k=a(window).height();e=a(this.grid.bDiv);var u=e.offset();var r=this.grid.oNext;var t=this.grid.oPrev;l=Math.max(l-Math.ceil(u.left)-this.p.nHoriExtra,this.p.nMinLimit);k=Math.max(k-Math.ceil(u.top)-this.p.nVertExtra,this.p.nMinLimit);l=this.p.width?0>this.p.width.indexOf("%")?parseInt(this.p.width,10):l*(parseInt(this.p.width,10)/100):l;k=this.p.height?0>this.p.height.indexOf("%")?parseInt(this.p.height,10):k*(parseInt(this.p.height,10)/100):k;if(l<=q&&k<=n)break;var w=this.offsetWidth,y=g.offsetHeight;
q=l;n=k;var m=q-w;var v=n-y;var x=0>m;u=0>v;var z;var A=z=!1;!x&&this.p.nWidthScroll>m&&(A=u||this.p.nWidthScroll>v);!u&&this.p.nWidthScroll>v&&(z=x||this.p.nWidthScroll>m);t&&t.grid.bHoriScroll&&(A=!1);A&&(x=!0);z&&(u=!0);r&&!this.p.bX1VScroll&&(u=!1);r=x?"scroll":"hidden";m=u?"scroll":"hidden";q=Math.min(q,w+(u?this.p.nWidthScroll:0));n=Math.min(n,y+(x?this.p.nWidthScroll:0));this.grid.bHoriScroll=x;this.grid.bVertScroll=u;this.grid.width=q;this.grid.height=n;t&&(x=n-(x?this.p.nWidthScroll:0)+(t.grid.bHoriScroll?
this.p.nWidthScroll:0),x!=t.grid.height&&(t.grid.height=x,w=t.grid.hDiv.offsetHeight,a(t.grid.bDiv).css("height",x+"px").parent().css({height:x+w+"px"})));a(this.grid.hDiv).width(q-(u?this.p.nWidthScroll:0));this.grid.firstRowHeight&&(t=this.grid.firstRowHeight,this.grid.firstRowHeight=null,a(this.grid.hDiv).height(this.grid.hDiv.offsetHeight-t));t=this.grid.hDiv.offsetHeight;e.css({width:q+"px",height:n+"px","overflow-x":r,"overflow-y":m}).parent().css({height:n+t+"px",width:q+"px"});q=l;n=k}this.grid.scrollGrid()}})};
return this.each(function(c){if("divHide"==this.parentNode.id||"divHide2"==this.parentNode.id){var e=this,g=a(e);c=a.extend(!0,{},b);var l=a.extend(!0,{},d),q=l.colModel=[];f(g);g.data("trTh").each(function(m){var v=a(this);v=v.attr("field")||v.text();q[m]={name:v,index:v,width:g.data("thw")[m]}});var n=!1,k=g.data("firstTr"),u=a(window).data("gantBody");0<u.length&&(n=!0);g.addClass("scroll");var r=e.parentNode;c.bHide=e.parentNode;c.bDiv=c.bHide.parentNode;(r=g.parents("#divPos")[0])&&a.each(["width",
"height"],function(){e.p&&e.p[this]?l[this]=e.p[this]:r.style[this]&&(l[this]=r.style[this],r.style[this]="auto")});a.each(l.colModel,function(m){"undefined"==typeof this.width&&(this.width=150)});var t=g.data("thead").get(0);g.data("trTh").each(function(m){"true"==a(this).attr("plusone")?a(this).css("width",l.colModel[m].width+"px"):(a(this).css("width",l.colModel[m].width+1+"px"),a(this).attr("plusone","true"))});c.hTable=document.createElement("table");var w=a(c.hTable);w.addClass(g.attr("class")).css({margin:"0px"});
a.each("cellspacing cellpadding border bordercolor frame rules".split(" "),function(m,v){g.attr(v)&&w.attr(v,g.attr(v))});w.attr("id","headerTable");g.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","").removeClass("visihidden")});r=t;t=a("#header",g);var y=[];for(a("input,select,textarea",t).each(function(m){"checkbox"==a(this).attr("type")?a(this).prop("checked")?y[m]="1":y[m]="0":y[m]=a(this).val()});r;)w.prepend(a(r).clone(!0)),r=r.previousSibling;
t=a(w).find("#header");a("input,select,textarea",t).each(function(m){"checkbox"==a(this).attr("type")?"1"==y[m]&&a(this).prop("checked",!0):a(this).val(y[m])});n&&k&&k[0]&&(c.firstRowHeight=g.data("trh")+1,a("td",k).each(function(m){a(this).css("width",g.data("tdw")[m]+"px").css("height",g.data("tdh")[m]+"px")}),jTrCl=k.clone(),a("td",jTrCl).each(function(m){a(this).html(""==a(this).text()?"":" ").css("backgroundColor","transparent")}),jAddTo=jTrCl.is("tr")?a(document.createElement("tbody")).appendTo(w):
w,jAddTo.append(jTrCl));c.hDiv=document.createElement("div");a(c.hDiv).attr("class","hGrid-header").append(a('<div style="width:10000em;" />').append(c.hTable));g.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","999").addClass("visihidden")});"hGrid-header"==a(c.bDiv).prev().attr("class")&&a(c.bDiv).prev().remove();a(c.bDiv).before(c.hDiv);a(c.bDiv).on("scroll",function(m){(m=a("table:first",m.target)[0])&&m.grid&&m.grid.scrollGrid()});r=a(window).data(l.sGridList);
0<u.length&&r&&(n=r[r.length-1],n.oWrap===u[0]&&(n.oTab.grid.oNext=e,c.oPrev=n.oTab));r||(r=[]);r.push({oTab:e,oWrap:u[0]});a(window).data(l.sGridList,r);g.data("cache",!1);e.grid=c;e.p=l;e=g=r=u=c=l=null}})}})(jQuery);
